# decision-making

1. check bank statements of some known banks
    * canara bank
    * kotak bank
    * icici bank

2. decide the cols or factors or metrics for our decision if we were to do with our brain

## metrics 

1. account number is needed to distinguish between different accounts
2. account holder name is needed again to distinguish between different accounts
3. bank name is needed to distinguish between different banks or accounts
4. credit or debit type for the transcation 
5. amount of the transcation
6. description—would be useful for LLM
7. the rest of the balance would be useful for LLM for decision-making
8. **Timestamp**-useful for identifying unique translations for an account 

### few things are not required 
1. issue date—not relevant
2. starting account balance—since we need balance of the account in every transcation
3. closing balance—since we need balance of the account in every transcation